@@ -22,6 +22,7 @@
 #define	_TRAYITEM_H
 
 #include <QAction>
+#include <QEvent>
 #include <QIcon>
 #include <QMenu>
 #include <QObject>
@@ -91,6 +92,9 @@ signals:
     void undock(TrayItem*);
     void about();
 
+protected:
+    bool event(QEvent *e);
+
 private:
     void minimizeEvent();
     void destroyEvent();
